@@ -1,3 +1,4 @@
+from six import string_types
 from django.utils.importlib import import_module
 
 
@@ -5,7 +6,7 @@ def import_callable(path_or_callable):
     if hasattr(path_or_callable, '__call__'):
         return path_or_callable
     else:
-        assert isinstance(path_or_callable, (str, unicode))
+        assert isinstance(path_or_callable, string_types)
         package, attr = path_or_callable.rsplit('.', 1)
         return getattr(import_module(package), attr)
 
